# Copyright 2015 Vince Veselosky and contributors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
__all__ = [
    "__author__",
    "__author_email__",
    "__copyright__",
    "__description__",
    "__license__",
    "__name__",
    "__url__",
    "__version__",
]

__author__ = "Vince Veselosky"
__author_email__ = "vince@veselosky.com"
__copyright__ = "2015 Vince Veselosky and contributors"
__description__ = "A Jinja2 template loader for AWS S3."
__license__ = "Apache 2.0"
__name__ = "jinja2_s3loader"
__url__ = 'https://github.com/veselosky/jinja2_s3loader'
__version__ = "0.2.0"

